@@ -1,3 +1,4 @@
+import sys
 import click
 
 import montecarlodata.settings as settings
@@ -23,7 +24,7 @@ def entry_point(ctx, profile, config_path):
     Entry point for all subcommands and options. Reads configuration and sets as context, except when configuring
     or getting help.
     """
-    if ctx.invoked_subcommand != settings.CONFIG_SUB_COMMAND and settings.HELP_FLAG not in click.get_os_args():
+    if ctx.invoked_subcommand != settings.CONFIG_SUB_COMMAND and settings.HELP_FLAG not in sys.argv[1:]:
         config = ConfigManager(profile_name=profile, base_path=config_path).read()
         if not config:
             ctx.abort()
