@@ -24,7 +24,7 @@ class CollectorManagementService:
         self._abort_on_error = True
         self._collector_region = aws_region_override or config.aws_region or DEFAULT_COLLECTION_REGION
 
-        self._request_wrapper = request_wrapper or GqlWrapper(mcd_id=config.mcd_id, mcd_token=config.mcd_token)
+        self._request_wrapper = request_wrapper or GqlWrapper(config)
         self._aws_wrapper = aws_wrapper or AwsClientWrapper(profile_name=aws_profile_override or config.aws_profile,
                                                             region_name=self._collector_region)
         self._user_service = user_service or UserService(request_wrapper=self._request_wrapper, config=config)
