@@ -13,6 +13,7 @@ from montecarlodata.fs_utils import mkdirs
 class Config:
     mcd_id: str
     mcd_token: str
+    mcd_api_endpoint: str
     aws_profile: Optional[str] = None
     aws_region: Optional[str] = None
 
@@ -50,6 +51,7 @@ class ConfigManager:
             return Config(
                 mcd_id=settings.MCD_DEFAULT_API_ID or self._config.get(self._profile_name, 'mcd_id'),
                 mcd_token=settings.MCD_DEFAULT_API_TOKEN or self._config.get(self._profile_name, 'mcd_token'),
+                mcd_api_endpoint=settings.MCD_API_ENDPOINT or self._config.get(self._profile_name, 'mcd_api_endpoint', fallback=settings.MCD_DEFAULT_API_ENDPOINT),
                 aws_profile=self._config.get(self._profile_name, 'aws_profile', fallback=None),
                 aws_region=self._config.get(self._profile_name, 'aws_region', fallback=None)
             )
