@@ -22,6 +22,8 @@ def manage_errors(func):
         except click.Abort:
             raise click.Abort()  # re-raise to prevent swallowing
         except Exception as error:
+            if hasattr(self, '_disable_handle_errors') and self._disable_handle_errors:
+                raise
             echo_error(error, [traceback.format_exc()])
 
         if hasattr(self, '_abort_on_error') and self._abort_on_error:
@@ -34,17 +36,17 @@ def echo_error(message: Any, errors: Optional[List[Any]] = None) -> None:
     """
     Convenience utility to echo any error in verbose and quiet mode
     """
-    click.echo(f'Error - {message}')
+    click.echo(f'Error - {message}', err=True)
     if settings.MCD_VERBOSE_ERRORS:
         for error in errors or []:
-            click.echo(error)
+            click.echo(error, err=True)
 
 
 def complain_and_abort(message: str) -> None:
     """
     Convenience utility to echo message and exit
     """
-    click.echo(f'Error - {message}')
+    click.echo(f'Error - {message}', err=True)
     raise click.Abort()
 
 
