@@ -12,12 +12,27 @@ from montecarlodata.integrations.onboarding.data_lake.hive import HiveOnboarding
 from montecarlodata.integrations.onboarding.data_lake.presto import PrestoOnboardingService
 from montecarlodata.integrations.onboarding.data_lake.spark import SparkOnboardingService, \
     SPARK_HTTP_MODE_CONFIG_TYPE, SPARK_DATABRICKS_CONFIG_TYPE, SPARK_BINARY_MODE_CONFIG_TYPE
-from montecarlodata.integrations.onboarding.fields import HIVE_MYSQL_CONNECTION_TYPE, GLUE_CONNECTION_TYPE, \
-    S3_METADATA_EVENT_TYPE, S3_QL_EVENT_TYPE, HIVE_S3_CONNECTION_TYPE
+from montecarlodata.integrations.onboarding.etl.dbt_cloud import DbtCloudOnboardingService
+from montecarlodata.integrations.onboarding.fields import (
+    AIRFLOW_LOGS_CONNECTION_TYPE,
+    AIRFLOW_LOGS_EVENT_TYPE,
+    CONNECTION_TO_WAREHOUSE_TYPE_MAP,
+    GLUE_CONNECTION_TYPE,
+    GQL_TO_FRIENDLY_CONNECTION_MAP,
+    HIVE_MYSQL_CONNECTION_TYPE,
+    HIVE_S3_CONNECTION_TYPE,
+    PRESTO_S3_CONNECTION_TYPE,
+    S3_METADATA_EVENT_TYPE,
+    S3_QL_EVENT_TYPE,
+    SECRETS_MANAGER_CREDENTIAL_MECHANISM,
+    SELF_HOSTING_MECHANISMS,
+)
 from montecarlodata.integrations.onboarding.operations.connection_ops import ConnectionOperationsService
+from montecarlodata.integrations.onboarding.self_hosted_credentials import SelfHostedCredentialOnboardingService
 from montecarlodata.integrations.onboarding.warehouse.warehouses import WarehouseOnboardingService
+from montecarlodata.integrations.keys import IntegrationKeyScope, IntegrationKeyService
 from montecarlodata.tools import add_common_options, validate_json_callback, AdvancedOptions, \
-    convert_uuid_callback
+    convert_uuid_callback, convert_empty_str_callback
 
 # Shared command verbiage
 METADATA_VERBIAGE = 'For metadata'
@@ -28,6 +43,7 @@ REGION_VERBIAGE = 'If not specified the region the collector is deployed in is u
 WAREHOUSE_VERBIAGE = 'For metadata, query logs and metrics'
 BI_VERBIAGE = 'For reports'
 PASSWORD_VERBIAGE = f'If you prefer a prompt (with hidden input) enter {settings.SHOW_PROMPT_VALUE}'
+RESOURCE_VERBIAGE = 'This can be helpful if the resources are in different accounts'
 
 # Options shared across commands
 ROLE_OPTIONS = [
@@ -106,14 +122,15 @@ def add_hive_metastore(ctx, database, **kwargs):
 @click.option('--port', help='HTTP port.', default=8889, type=click.INT, show_default=True)
 @click.option('--user', help='Username with access to catalog/schema.', required=False)
 @click.option('--password', help=f'User\'s password. {PASSWORD_VERBIAGE}', required=False, cls=AdvancedOptions, prompt_if_requested=True)
-@click.option('--catalog', help='Mount point to access data source.', required=True)
-@click.option('--schema', help='Schema to access.', required=True)
+@click.option('--catalog', help='Mount point to access data source.', required=False)
+@click.option('--schema', help='Schema to access.', required=False)
 @click.option('--http-scheme', help='Scheme for authentication.',
               type=click.Choice(['http', 'https'], case_sensitive=True), required=True)
 @click.option('--cert-file', help='Local SSL certificate file to upload to collector.', required=False,
               type=click.Path(dir_okay=False, exists=True), cls=AdvancedOptions, mutually_exclusive_options=['cert_s3'])
 @click.option('--cert-s3', help='Object path (key) to a certificate already uploaded to the collector.',
               required=False, cls=AdvancedOptions, mutually_exclusive_options=['cert_file'])
+@click.option('--skip-cert-verification', help='Skip SSL certificate verification.', required=False, is_flag=True)
 @add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
 def add_presto(ctx, password, **kwargs):
@@ -131,6 +148,8 @@ def add_presto(ctx, password, **kwargs):
 @click.option('--database', help='Name of database.', required=False)
 @click.option('--port', help='HTTP port.', default=10000, type=click.INT, show_default=True)
 @click.option('--user', help='Username with access to hive.', required=True)
+@click.option('--auth-mode', help='Hive authentication mode.', required=False, default='SASL',
+              type=click.Choice(['SASL', 'NOSASL']), show_default=True)
 @add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
 def add_hive(ctx, user, **kwargs):
@@ -174,7 +193,7 @@ def add_glue(ctx, role, region, **kwargs):
     GlueAthenaOnboardingService(config=ctx['config']).onboard_glue(assumable_role=role, aws_region=region, **kwargs)
 
 
-@integrations.command(help=f'Setup an Athena integration. For query logs and health queries.')
+@integrations.command(help='Setup an Athena integration. For query logs and health queries.')
 @click.pass_obj
 @click.option('--catalog', help='Glue data catalog. If not specified the AwsDataCatalog is used.', required=False)
 @click.option('--workgroup',
@@ -284,6 +303,58 @@ def add_bigquery(ctx, key_file, name, **kwargs):
     WarehouseOnboardingService(config=ctx['config']).onboard_bq(ServiceFile=key_file, warehouseName=name, **kwargs)
 
 
+@integrations.command(help='Setup an integration that uses self-hosted credentials.')
+@click.pass_obj
+@click.option(
+    '--connection-type',
+    help='Type of connection.',
+    required=True,
+    type=click.Choice(GQL_TO_FRIENDLY_CONNECTION_MAP.keys(), case_sensitive=False),
+    cls=AdvancedOptions,
+    values_with_required_options=CONNECTION_TO_WAREHOUSE_TYPE_MAP.keys(),
+    required_options_for_values=['name'],
+)
+@click.option(
+    '--mechanism',
+    help='Credential self-hosting mechanism.',
+    required=True,
+    type=click.Choice(SELF_HOSTING_MECHANISMS, case_sensitive=False),
+    default=SECRETS_MANAGER_CREDENTIAL_MECHANISM,
+)
+@click.option('--key', help='Identifier for credentials within self-hosting mechanism.', required=True)
+@click.option('--name', help='Friendly name for the warehouse. Required for warehouses.', required=False)
+@add_common_options(ROLE_OPTIONS)
+@add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
+@click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
+def add_self_hosted_credentials(ctx, mechanism, key, role, name, **kwargs):
+    """
+    Onboard a connection with self-hosted credentials
+    """
+    SelfHostedCredentialOnboardingService(config=ctx['config']).onboard_connection(
+        self_hosting_mechanism=mechanism,
+        self_hosting_key=key,
+        assumable_role=role,
+        warehouseName=name,
+        **kwargs
+    )
+
+
+@integrations.command(help=f'Toggle S3 events for Airflow task logs.')
+@click.pass_obj
+@add_common_options(EVENT_OPTIONS)
+@add_common_options(ROLE_OPTIONS)
+@click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
+def toggle_airflow_log_events(ctx, toggle, role, **kwargs):
+    """
+    Toggle s3 events for Airflow task logs
+    """
+    EventsOnboardingService(config=ctx['config']).toggle_event_configuration(enable=toggle,
+                                                                             connection_type=AIRFLOW_LOGS_CONNECTION_TYPE,
+                                                                             event_type=AIRFLOW_LOGS_EVENT_TYPE,
+                                                                             assumable_role=role,
+                                                                             **kwargs)
+
+
 @integrations.command(help=f'Toggle S3 metadata events for Hive/Presto. {EVENT_VERBIAGE}.')
 @click.pass_obj
 @add_common_options(EVENT_OPTIONS)
@@ -314,19 +385,28 @@ def toggle_glue_metadata_events(ctx, toggle):
 @click.pass_obj
 @add_common_options(EVENT_OPTIONS)
 @add_common_options(ROLE_OPTIONS)
-@click.option('--type', help='Type of the integration.', type=click.Choice(['hive-emr'], case_sensitive=True),
-              required=True, default='hive-emr', show_default=True)
+@click.option('--connection-type', help='Type of the integration.',
+              type=click.Choice([HIVE_S3_CONNECTION_TYPE, PRESTO_S3_CONNECTION_TYPE], case_sensitive=True),
+              required=False)
+@click.option('--format-type', help='Query log format.',
+              type=click.Choice(['hive-emr', 'custom'], case_sensitive=True),
+              required=False)
+@click.option('--source-format', help='Query log file format. Only required when "custom" is used.',
+              type=click.Choice(['json', 'jsonl'], case_sensitive=True),
+              required=False)
+@click.option('--mapping-file',
+              help='Mapping of expected to existing query log fields. Only required if "custom" is used.',
+              type=click.Path(exists=True),
+              required=False)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def toggle_ql_events(ctx, toggle, role, external_id, type):
+def toggle_ql_events(ctx, toggle, role, **kwargs):
     """
     Toggle s3 query log events for a lake
     """
     EventsOnboardingService(config=ctx['config']).toggle_event_configuration(enable=toggle,
-                                                                             connection_type=HIVE_S3_CONNECTION_TYPE,
                                                                              event_type=S3_QL_EVENT_TYPE,
                                                                              assumable_role=role,
-                                                                             external_id=external_id,
-                                                                             format_type=type)
+                                                                             **kwargs)
 
 
 @integrations.command(help=f'Setup a Tableau integration. {BI_VERBIAGE}.')
@@ -371,9 +451,17 @@ def add_looker(ctx, **kwargs):
 
 @integrations.command(help=f'Setup a Looker ML (git) integration. {BI_VERBIAGE}.')
 @click.pass_obj
-@click.argument('ssh-key', required=True, type=click.Path(dir_okay=False, exists=True))
+@click.option('--ssh-key', help='The ssh key for git ssh integrations.', required=False,
+              type=click.Path(dir_okay=False, exists=True),
+              cls=AdvancedOptions, mutually_exclusive_options=['token', 'username'])
 @click.option('--repo-url', help='Repository URL as ssh://[user@]server/project.git or the shorter '
-                                 'form [user@]server:project.git.', required=True)
+                                 'form [user@]server:project.git for ssh. For https, use https://server/project.git.',
+              required=True)
+@click.option('--token', help='Git Access Token to be used for Https instead of ssh key.', required=False,
+              cls=AdvancedOptions, mutually_exclusive_options=['ssh-key'])
+@click.option('--username', help='Git username to be used in conjunction with the access token. This is only '
+                                 'required for BitBucket integrations.',
+              cls=AdvancedOptions, required=False, mutually_exclusive_options=['ssh-key'])
 @add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 def add_looker_git(ctx, **kwargs):
     """
@@ -382,7 +470,23 @@ def add_looker_git(ctx, **kwargs):
     ReportsOnboardingService(config=ctx['config']).onboard_looker_git(**kwargs)
 
 
-@integrations.command(help=f'List all active connections.', name='list')
+@integrations.command(help=f'Setup a dbt Cloud integration.')
+@click.pass_obj
+@click.option('--dbt-cloud-api-token', 'dbt_cloud_api_token', help=f'dbt Cloud API token. {PASSWORD_VERBIAGE}.',
+              required=True, cls=AdvancedOptions, prompt_if_requested=True)
+@click.option('--dbt-cloud-account-id', 'dbt_cloud_account_id', help='dbt Cloud Account ID.', required=True)
+@click.option('--connection-id', 'connection_id', required=False,
+              help='ID of warehouse connection to link with dbt Cloud. '
+                   'Required if there are multiple warehouse connections present.')
+@add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
+def add_dbt_cloud(ctx, **kwargs):
+    """
+    Onboard a looker metadata connection
+    """
+    DbtCloudOnboardingService(config=ctx['config']).onboard_dbt_cloud(**kwargs)
+
+
+@integrations.command(help='List all active connections.', name='list')
 @click.pass_obj
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
 def display_integrations(ctx):
@@ -406,7 +510,7 @@ def create_role(ctx, file, aws_profile):
     CloudResourceService(config=ctx['config'], aws_profile_override=aws_profile).create_role(path_to_policy_doc=file)
 
 
-@integrations.command(help=f'Update credentials for a connection.', name='update')
+@integrations.command(help='Update credentials for a connection. Only replaces/inserts the keys in changes by default.', name='update')
 @click.pass_obj
 @add_common_options(CONNECTION_OPTIONS)
 @click.option('--changes', help="""
@@ -416,16 +520,21 @@ def create_role(ctx, file, aws_profile):
               E.g. --changes '{"user":"Apollo"}'
               """, required=True, callback=validate_json_callback)
 @click.option('--skip-validation', help='Skip validating credentials.', default=False, show_default=True, is_flag=True)
+@click.option('--replace-all', help='Replace all credentials rather than just inserting/updating the keys in changes.', default=False, show_default=True, is_flag=True)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def update_credentials(ctx, connection_id, changes, skip_validation):
+def update_credentials(ctx, connection_id, changes, skip_validation, replace_all):
     """
     Update credentials for a connection
     """
-    ConnectionOperationsService(config=ctx['config']).update_credentials(connection_id=connection_id, changes=changes,
-                                                                         should_validate=not skip_validation)
+    ConnectionOperationsService(config=ctx['config']).update_credentials(
+        connection_id=connection_id,
+        changes=changes,
+        should_validate=not skip_validation,
+        should_replace=replace_all
+    )
 
 
-@integrations.command(help=f'Remove an existing connection. Deletes any associated jobs, monitors, etc.', name='remove')
+@integrations.command(help='Remove an existing connection. Deletes any associated jobs, monitors, etc.', name='remove')
 @click.pass_obj
 @add_common_options(CONNECTION_OPTIONS)
 @click.option('--no-prompt', help='Don\'t ask for confirmation.', default=False, show_default=True, is_flag=True)
@@ -437,7 +546,7 @@ def remove_connection(ctx, **kwargs):
     ConnectionOperationsService(config=ctx['config']).remove_connection(**kwargs)
 
 
-@integrations.command(help=f'Retest an existing connection.', name='test')
+@integrations.command(help='Retest an existing connection.', name='test')
 @click.pass_obj
 @add_common_options(CONNECTION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
@@ -446,3 +555,56 @@ def echo_test_existing(ctx, **kwargs):
     Tests an existing connection and echos results in pretty JSON.
     """
     ConnectionOperationsService(config=ctx['config']).echo_test_existing(**kwargs)
+
+
+@integrations.command(help='Setup S3 event notifications for a lake.')
+@click.pass_obj
+@click.option('--bucket', 'bucket_name', required=True, help='Name of bucket to enable events for.')
+@click.option('--prefix', default=None, callback=convert_empty_str_callback, required=False,
+              help='Limit the notifications to objects starting with a prefix (e.g. \'data/\').')
+@click.option('--suffix', default=None, callback=convert_empty_str_callback, required=False,
+              help='Limit notifications to objects ending with a suffix (e.g. \'.csv\').')
+@click.option('--topic-arn', default=None, callback=convert_empty_str_callback, required=False,
+              help='Use an existing SNS topic (same region as the bucket). Creates a topic if one is not specified or '
+                   'if an MCD topic does not already exist in the region.')
+@click.option('--collector-aws-profile', required=False,
+              help=f'Override the AWS profile use by the CLI for operations on SQS/Collector. {RESOURCE_VERBIAGE}.')
+@click.option('--resource-aws-profile', 'bucket_aws_profile', required=False,
+              help=f'Override the AWS profile use by the CLI for operations on S3/SNS. {RESOURCE_VERBIAGE}.')
+@click.option('--event-type', required=True, default=CloudResourceService.MCD_EVENT_TYPE_MD, show_default=True,
+              help='Type of event to setup.',
+              type=click.Choice(CloudResourceService.MCD_EVENT_TYPE_FRIENDLY_TO_COLLECTOR_OUTPUT_MAP.keys(), case_sensitive=True))
+@click.option('--auto-yes', is_flag=True, help='Skip any interactive approval.', default=False, show_default=True)
+@add_common_options(DISAMBIGUATE_DC_OPTIONS)
+@click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
+def add_events(ctx, **kwargs):
+    CloudResourceService(config=ctx['config'], aws_wrapper=None).add_events(**kwargs)
+
+
+@integrations.command(help='Create an integration key. The resulting key id and secret will be printed to the console.')
+@click.pass_obj
+@click.option('--description',
+              required=True,
+              help='Key description.')
+@click.option('--scope',
+              required=True,
+              type=click.Choice(IntegrationKeyScope.values(), case_sensitive=False),
+              help='Key scope (integration the key can be used for).')
+@click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
+def create_key(ctx, **kwargs):
+    IntegrationKeyService(config=ctx['config']).create(**kwargs)
+
+
+@integrations.command(help='Delete an integration key.')
+@click.pass_obj
+@click.option('--key-id', required=True, help='Integration key id.')
+@click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
+def delete_key(ctx, **kwargs):
+    IntegrationKeyService(config=ctx['config']).delete(**kwargs)
+
+
+@integrations.command(help='List all integration keys.')
+@click.pass_obj
+@click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
+def list_keys(ctx):
+    IntegrationKeyService(config=ctx['config']).get_all()
