@@ -2,6 +2,7 @@ from typing import Optional
 
 import click
 
+from montecarlodata.common.common import read_as_json_string
 from montecarlodata.config import Config
 from montecarlodata.errors import complain_and_abort, manage_errors
 from montecarlodata.integrations.onboarding.base import BaseOnboardingService
@@ -23,6 +24,9 @@ class EventsOnboardingService(BaseOnboardingService):
 
         if num_of_warehouses == 1:
             kwargs['dwId'] = self._user_service.warehouses[0]['uuid']
+            mapping_file = kwargs.pop('mapping_file', None)
+            if mapping_file:
+                kwargs['mapping'] = read_as_json_string(mapping_file)
             variables = self._request_wrapper.convert_snakes_to_camels(kwargs)
             status = self._request_wrapper.make_request(query=TOGGLE_EVENT_MUTATION, variables=variables).get(
                 EXPECTED_TOGGLE_EVENTS_GQL_RESPONSE_FIELD, {}).get('success')
