@@ -25,8 +25,8 @@ mutation testDatabaseCredentials($assumableRole:String, $connectionType:String,
 """
 
 TEST_HIVE_SQL_CRED_MUTATION = """
-mutation testHiveCredentials($database:String, $host:String, $port:Int, $username:String, $connectionOptions:ConnectionTestOptions) {
-  testHiveCredentials(database:$database, host:$host, port:$port, username:$username, connectionOptions:$connectionOptions) {
+mutation testHiveCredentials($database:String, $host:String, $port:Int, $username:String, $authMode:String, $connectionOptions:ConnectionTestOptions) {
+  testHiveCredentials(database:$database, host:$host, port:$port, username:$username, authMode:$authMode, connectionOptions:$connectionOptions) {
     key
   }
 }
@@ -118,9 +118,17 @@ mutation testBqCredentials($serviceJson:String, $connectionOptions:ConnectionTes
 }
 """
 
+TEST_SELF_HOSTED_CRED_MUTATION = """
+mutation testSelfHostedCredentials($connectionType:String, $selfHostingMechanism:String, $selfHostingKey:String, $assumableRole:String, $externalId:String, $region:String, $connectionOptions:ConnectionTestOptions) {
+  testSelfHostedCredentials(connectionType:$connectionType, selfHostingMechanism:$selfHostingMechanism, selfHostingKey:$selfHostingKey, assumableRole:$assumableRole, externalId:$externalId, region:$region, connectionOptions:$connectionOptions) {
+    key
+  }
+}
+"""
+
 TOGGLE_EVENT_MUTATION = """
-mutation toggleEventConfig($dwId:UUID!, $enable:Boolean!, $connectionType:String!, $eventType:DataCollectorEventTypes!, $assumableRole:String, $externalId:String, $formatType:String) {
-  toggleEventConfig(dwId:$dwId, enable:$enable, connectionType:$connectionType, eventType: $eventType, assumableRole:$assumableRole, externalId:$externalId, formatType:$formatType){
+mutation toggleEventConfig($dwId:UUID!, $enable:Boolean!, $connectionType:String!, $eventType:DataCollectorEventTypes!, $assumableRole:String, $externalId:String, $formatType:String, $sourceFormat:String, $mapping:JSONString) {
+  toggleEventConfig(dwId:$dwId, enable:$enable, connectionType:$connectionType, eventType: $eventType, assumableRole:$assumableRole, externalId:$externalId, formatType:$formatType, sourceFormat:$sourceFormat, mapping:$mapping){
     success
   }
 }
@@ -137,8 +145,8 @@ mutation addConnection($connectionType:String!, $createWarehouseType:String, $dw
 """
 
 UPDATE_CREDENTIALS_MUTATION = """
-mutation updateCredentials($connectionId: UUID!, $changes:JSONString!, $shouldValidate:Boolean) {
-  updateCredentials(connectionId:$connectionId, changes:$changes, shouldValidate:$shouldValidate){
+mutation updateCredentials($connectionId: UUID!, $changes:JSONString!, $shouldValidate:Boolean, $shouldReplace:Boolean) {
+  updateCredentials(connectionId:$connectionId, changes:$changes, shouldValidate:$shouldValidate, shouldReplace:$shouldReplace){
     success
   }
 }
@@ -215,6 +223,15 @@ mutation testLookerGitSshCredentials($connectionOptions:ConnectionTestOptions, $
 }
 """
 
+TEST_LOOKER_GIT_CLONE_CRED_MUTATION = """
+mutation testLookerGitCloneCredentials($connectionOptions:ConnectionTestOptions, $repoUrl:String!, $sshKey:String, $username:String, $token:String) {
+  testLookerGitCloneCredentials(connectionOptions:$connectionOptions, repoUrl:$repoUrl, sshKey:$sshKey, username:$username, token:$token) {
+    key
+    success
+  }
+}
+"""
+
 ADD_BI_CONNECTION_MUTATION = """
 mutation addBiConnection($connectionType:String!, $key:String!, $dcId:UUID) {
   addBiConnection(connectionType:$connectionType, key:$key, dcId:$dcId){
@@ -223,4 +240,19 @@ mutation addBiConnection($connectionType:String!, $key:String!, $dcId:UUID) {
     }
   }
 }
+"""
+
+TEST_DBT_CLOUD_CRED_MUTATION = """
+mutation testDbtCloudCredentials( 
+    $dbtCloudApiToken: String,
+    $dbtCloudAccountId: String, 
+    $connectionOptions:ConnectionTestOptions) {
+  testDbtCloudCredentials(
+      dbtCloudApiToken:$dbtCloudApiToken,
+      dbtCloudAccountId:$dbtCloudAccountId,
+      connectionOptions:$connectionOptions) {
+    key
+    success
+  }
+}
 """
\ No newline at end of file
