@@ -8,6 +8,7 @@ from box import Box, BoxList
 from retry import retry
 
 import montecarlodata.settings as settings
+from montecarlodata.config import Config
 from montecarlodata.common.common import boxify
 from montecarlodata.common.data import MonolithResponse
 from montecarlodata.errors import manage_errors, complain_and_abort, abort_on_gql_errors
@@ -20,10 +21,10 @@ class Wrapper:
 
 
 class GqlWrapper(Wrapper):
-    def __init__(self, mcd_id: str, mcd_token: str, **kwargs):
-        self._mcd_id = mcd_id
-        self._mcd_token = mcd_token
-        self._endpoint = settings.MCD_API_ENDPOINT
+    def __init__(self, config: Config, **kwargs):
+        self._mcd_id = config.mcd_id
+        self._mcd_token = config.mcd_token
+        self._endpoint = config.mcd_api_endpoint
 
         super().__init__(**kwargs)
 
